==> TOBARA-1.0.2.tar.gz: TOBARA-1.0.2/README.md <==
<p align="center">
  <img src="https://github.com/MiguelRAvila/projectTOBARA/blob/master/images/logo.png?raw=true" alt="TOBARALogo"/>
  
  <h3 > projectTOBARA: The Only Boolean Algebra Reduction App</h3>
</p>

[![Inline docs](http://inch-ci.org/github/dwyl/hapi-auth-jwt2.svg?branch=master)](https://github.com/MiguelRAvila/projectTOBARA/tree/master/docs)
![version](https://img.shields.io/badge/version-1.0.2-blue)
<a href='#'><img src='https://img.shields.io/badge/python-3.6-blue.svg'></a>
<a href='https://pypi.org/project/TOBARA/#history'><img src='https://img.shields.io/pypi/v/gluonnlp.svg'></a>

TOBARA (The Only Boolean Algebra Reduction App) is a toolkit of Boolean function analysis whose main task is to reduce Boolean functions as much as possible. Our objetive is to determine information about the function like variables, terms and then reduce the function.  

* [Quick Stat Guide](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/QuickStart.md)
* [Each Function Documentation](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/Function_Documentation.md)
* [Documentation](https://github.com/MiguelRAvila/projectTOBARA/blob/master/info/Documentation.md)

## News
The News Section is the way we represent the advances of our project, you can find all of the journals here: [Journals](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/Journey)


* [TOBARA 1.0.2 Released! Getting better documentation](https://pypi.org/project/TOBARA/)
* [TOBARA 1.0.1 Released! Getting better code](https://pypi.org/project/TOBARA/)
* [TOBARA 1.0.0 Released!](https://pypi.org/project/TOBARA/)
* [Function "minTerm" finished!](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/Journey/MinTerms-27-May-2020.md)
* [Library Research finished](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/Journey/Library_Research-02-June-2020.md)
* [Function "getMinTable" finished!](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/Journey/GetMinTable_Function-22-May-2020.md)
* [Function "getTable" finished](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/Journey/GetTable_Function-14-April-2020.md)
* [Function "bin" finished](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/Journey/Bin_Function-07-April-2020.md)
## Installation

Make sure you have Python 3.6 or newer.
You can install it with pip:

```shell
pip install TOBARA
```
If you are in linux:

```shell
python3 -m pip install TOBARA
```
## Docs

projectTOBARA documentation is available here: [Documentation](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs)
Here you can find our Journals where we wrote all of our advances in the Project
Also you can check the documents that we wrote for our project.

## Team Organization:

Our team organization is available here: [Team Organization](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/TOBARA_Documentation.pdf)

==> TOBARA-1.0.3.tar.gz: TOBARA-1.0.3/README.md <==
<p align="center">
  <img src="https://github.com/MiguelRAvila/projectTOBARA/blob/master/images/logo.png?raw=true" alt="TOBARALogo"/>
  
  <h3 > projectTOBARA: The Only Boolean Algebra Reduction App</h3>
</p>

[![Inline docs](http://inch-ci.org/github/dwyl/hapi-auth-jwt2.svg?branch=master)](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs)
![version](https://img.shields.io/badge/version-1.0.3-blue)
<a href='#'><img src='https://img.shields.io/badge/python-3.6-blue.svg'></a>
<a href='https://pypi.org/project/TOBARA/#history'><img src='https://img.shields.io/pypi/v/gluonnlp.svg'></a>

TOBARA (The Only Boolean Algebra Reduction App) is a toolkit of Boolean function analysis whose main task is to reduce Boolean functions as much as possible. Our objetive is to determine information about the function like variables, terms and then reduce the function.  

* [Quick Start Guide](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/QuickStart.md)
* [Each Function Documentation](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/Function_Documentation.md)
* [Documentation](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/Documentation.md)

### You can also find our project in PyPI! [PyPI Project](https://pypi.org/project/TOBARA/)

## News
The News Section is the way we represent the advances of our project, you can find all of the journals here: [Journals](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/Journey)


* [TOBARA 1.0.3 Released! Minor fixes](https://pypi.org/project/TOBARA/)
* [TOBARA 1.0.2 Released! Getting better documentation](https://pypi.org/project/TOBARA/)
* [TOBARA 1.0.1 Released! Getting better code](https://pypi.org/project/TOBARA/)
* [TOBARA 1.0.0 Released!](https://pypi.org/project/TOBARA/)
* [Function "minTerm" finished!](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/Journey/MinTerms-27-May-2020.md)
* [Library-Research finished](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/Journey/Library_Research-02-June-2020.md)
* [Function "getMinTable" finished!](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/Journey/GetMinTable_Function-22-May-2020.md)
* [Function "getTable" finished](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/Journey/GetTable_Function-14-April-2020.md)
* [Function "bin" finished](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/Journey/Bin_Function-07-April-2020.md)
## Installation

Make sure you have Python 3.6 or newer.
You can install it with pip:

```shell
pip install TOBARA
```
If you are in linux:

```shell
python3 -m pip install TOBARA
```
## Docs

projectTOBARA documentation is available here: [Documentation](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs)
Here you can find our Journals where we wrote all of our advances in the Project
Also you can check the documents that we wrote for our project.

## Team Organization:

Our team organization is available here: [Team Organization](https://github.com/MiguelRAvila/projectTOBARA/blob/master/docs/TOBARA_Documentation.pdf)

## Test

Our project works in Python (Up to version 3.6) You can find our test here:
* [Our tests](https://github.com/Apoquinto/TOBARA-Testing/blob/master/Tests.ipynb)
